@@ -123,6 +123,7 @@ Internals! {
     root_down: "move tree root down" true,
     root_up: "move tree root up" true,
     select: "select a file by path" true,
+    show: "reveal and select a file by path" true,
     select_first: "select the first item" false,
     select_last: "select the last item" false,
     set_panel_width: "set the width of a panel" false,
@@ -170,6 +171,7 @@ impl Internal {
             Internal::apply_flags => r"-(?P<flags>\w+)?",
             Internal::focus => r"focus (?P<path>.*)?",
             Internal::select => r"select (?P<path>.*)?",
+            Internal::show => r"show (?P<path>.*)?",
             Internal::line_down => r"line_down (?P<count>\d*)?",
             Internal::line_up => r"line_up (?P<count>\d*)?",
             Internal::line_down_no_cycle => r"line_down_no_cycle (?P<count>\d*)?",
